==> ocg_location-0.0.4.tar.gz: lib/src/screens/location_picker_screen.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_location/src/blocs/location_current.dart';
import 'package:ocg_location/src/blocs/location_detail.dart';
import 'package:ocg_location/src/models/location_response.dart';
import 'package:ocg_location/src/widgets/location_pick_map.dart';

class LocationPickerScreen extends StatefulWidget {
  const LocationPickerScreen({Key key}) : super(key: key);

  @override
  State<StatefulWidget> createState() => _LocationPickerScreenState();
}

class _LocationPickerScreenState extends State<LocationPickerScreen> {
  LocationResponse request;
  LocationPickController controller;

  @override
  void initState() {
    super.initState();
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }

  void getCurrentLocation() {
    BlocProvider.of<LocationCurrentBloc>(context)
        .add(LocationCurrentRefreshEvent());
  }

  void refreshLocation(LatLng position) {
    BlocProvider.of<LocationDetailBloc>(context)
        .add(LocationDetailPositionEvent(position));
  }

  Widget buildLocationBar() {
    return BlocListener<LocationCurrentBloc, LocationCurrentState>(
      listener: (context, state) {
        if (state is LocationCurrentLoadedState) {
          controller.moveTo(state.currentLocation);
        }
      },
      child: BlocBuilder<LocationDetailBloc, LocationDetailState>(
          builder: (context, locationDetailState) {
        LocationResponse location;
        if (locationDetailState is LocationDetailLoadedState) {
          location = locationDetailState.location;
        }
        return SafeArea(
          child: Card(
            elevation: 5.0,
            margin: EdgeInsets.all(12.0),
            shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(4.0)),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.all(12.0),
                  child: Row(
                    children: <Widget>[
                      Icon(Icons.location_on),
                      Expanded(
                          child: Padding(
                        padding: const EdgeInsets.only(left: 4.0),
                        child: Text(
                          location?.fullAddress ?? "Searching Location",
                          style: TextStyle(
                            fontSize: 18.0,
                          ),
                          maxLines: 4,
                        ),
                      )),
                    ],
                  ),
                ),
                (locationDetailState is LocationDetailLoadingState)
                    ? LinearProgressIndicator()
                    : Container(height: 2.0)
              ],
            ),
          ),
        );
      }),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Stack(
        children: <Widget>[
          LocationPickupMap(
            controllerCompleted: (controller) {
              this.controller = controller;
              getCurrentLocation();
            },
            onPositionChanged: (position) {
              refreshLocation(position);
            },
          ),
          buildLocationBar(),
        ],
      ),
      floatingActionButton: FloatingActionButton(
        child: Icon(
          Icons.my_location,
          color: Theme.of(context).primaryColor,
        ),
        backgroundColor: Colors.white,
        onPressed: getCurrentLocation,
      ),
      bottomNavigationBar: Padding(
        padding: const EdgeInsets.all(16.0),
        child: RoundedButton(
          "Continue",
          onTap: () {
            Navigator.of(context).pop(this.request);
          },
          color: Theme.of(context).primaryColor,
          borderRadius: 12,
          padding: EdgeInsets.symmetric(horizontal: 12, vertical: 16),
        ),
      ),
    );
  }
}

==> ocg_location-0.0.11.tar.gz: lib/src/screens/location_picker_screen.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:google_maps_flutter/google_maps_flutter.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_location/ocg_location.dart';
import 'package:ocg_location/src/blocs/location_current.dart';
import 'package:ocg_location/src/blocs/location_detail.dart';
import 'package:ocg_location/src/models/address.dart';
import 'package:ocg_location/src/widgets/location_pick_map.dart';

class LocationPickerScreen extends StatefulWidget {
  const LocationPickerScreen({Key key}) : super(key: key);

  @override
  State<StatefulWidget> createState() => _LocationPickerScreenState();
}

class _LocationPickerScreenState extends State<LocationPickerScreen> {
  Address request;
  LocationPickController controller;

  @override
  void initState() {
    super.initState();
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }

  void getCurrentLocation() {
    BlocProvider.of<LocationCurrentBloc>(context)
        .add(LocationCurrentRefreshEvent());
  }

  void refreshLocation(LatLng position) {
    BlocProvider.of<LocationDetailBloc>(context).add(
        LocationDetailPositionEvent(
            Position(position.latitude, position.longitude)));
  }

  Widget buildLocationBar() {
    return BlocListener<LocationCurrentBloc, LocationCurrentState>(
      listener: (context, state) {
        if (state is LocationCurrentLoadedState) {
          controller.moveTo(LatLng(
              state.currentLocation.latitude, state.currentLocation.longitude));
        }
      },
      child: BlocBuilder<LocationDetailBloc, LocationDetailState>(
          builder: (context, locationDetailState) {
        Address location;
        if (locationDetailState is LocationDetailLoadedState) {
          location = locationDetailState.location;
        }
        return SafeArea(
          child: Card(
            elevation: 5.0,
            margin: EdgeInsets.all(12.0),
            shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(4.0)),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.all(12.0),
                  child: Row(
                    children: <Widget>[
                      Icon(Icons.location_on),
                      Expanded(
                          child: Padding(
                        padding: const EdgeInsets.only(left: 4.0),
                        child: Text(
                          location?.fullAddress ?? "Searching Location",
                          style: TextStyle(
                            fontSize: 18.0,
                          ),
                          maxLines: 4,
                        ),
                      )),
                    ],
                  ),
                ),
                (locationDetailState is LocationDetailLoadingState)
                    ? LinearProgressIndicator()
                    : Container(height: 2.0)
              ],
            ),
          ),
        );
      }),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Stack(
        children: <Widget>[
          LocationPickupMap(
            controllerCompleted: (controller) {
              this.controller = controller;
              getCurrentLocation();
            },
            onPositionChanged: (position) {
              refreshLocation(position);
            },
          ),
          buildLocationBar(),
        ],
      ),
      floatingActionButton: FloatingActionButton(
        child: Icon(
          Icons.my_location,
          color: Theme.of(context).primaryColor,
        ),
        backgroundColor: Colors.white,
        onPressed: getCurrentLocation,
      ),
      bottomNavigationBar: Padding(
        padding: const EdgeInsets.all(16.0),
        child: RoundedButton(
          "Continue",
          onTap: () {
            Navigator.of(context).pop(this.request);
          },
          color: Theme.of(context).primaryColor,
          borderRadius: 12,
          padding: EdgeInsets.symmetric(horizontal: 12, vertical: 16),
        ),
      ),
    );
  }
}
